import { useSyncExternalStore } from 'react';
function createStore() {
  if (typeof document === "undefined") {
    return {
      subscribe: () => () => {},
      getSnapshot: () => "light",
      getServerSnapshot: () => "light"
    };
  }
  const matchMedia = window.matchMedia("(prefers-color-scheme: dark)");
  return {
    subscribe: onStoreChange => {
      matchMedia.addEventListener("change", onStoreChange);
      return () => matchMedia.removeEventListener("change", onStoreChange);
    },
    getSnapshot: () => matchMedia.matches ? "dark" : "light",
    getServerSnapshot: () => "light"
  };
}
const store = createStore();
function usePrefersColorScheme() {
  return useSyncExternalStore(store.subscribe, store.getSnapshot, store.getServerSnapshot);
}
export { usePrefersColorScheme };
//# sourceMappingURL=usePrefersColorScheme.js.map
